@@ -36,7 +36,7 @@ class SMBShareSelectDialog(KDialogBase):
         
         vbox = self.makeVBoxMainWidget()
 
-        hbox = TTQHBox(vbox)
+        hbox = TQHBox(vbox)
         hbox.setSpacing(self.spacingHint())
         tmplabel = TQLabel(hbox)
         tmplabel.setPixmap(UserIcon("hi32-samba"))
